/*
 * Animates any property of a view with setInterval()
 */

var Animator = (function(){
	var view;
	var interval;
	var duration;
	var currentInterval;
	var totalIntervals;
	var property;
	var propInterval;

	var animationInterval;

	var callback;

	/*
	 * main functin to call for animating.
	 * @param params.view Ti.UI.View to animate
	 * @param params.interval interval to use (ms)
	 * @param params.duration time to animate the view (ms)
	 * @param params.[property] property to animate, receive any Ti.UI.View property, where property is the actual name (e.g. params.height) and its value the expected new value for that property
	 * @example  animate({
		view : foo,
		interval : 10,
		duration : 1000,
		top : 50
	 })
	 Will animate top's foo for 1 second until it reaches 50
	 */
	function animate(params, newCallback){
		var params 			= params || {};
			view 			= params.view;
			interval 		= params.interval || 25;
			duration 		= params.duration || 0;
			property		= _.difference(_.keys(params), ['view', 'interval', 'duration'])[0];
		
			totalIntervals 	= duration / interval;
		var propToHave		= params[property];
		var propHaving		= view[property];
			propInterval	= (propToHave - propHaving) / totalIntervals;
		
			currentInterval = 0;
		
		animationInterval 	= setInterval(animation, interval);

		callback = newCallback;
	}

	function animation(){
		if(currentInterval >= totalIntervals){
			clearInterval(animationInterval);
			callback && callback();
			callback = null;
		} else {
			view[property] += propInterval;
			currentInterval++;
			Ti.API.info('property: ' + view[property]);
		}
	}

	return {
		animate : animate
	};

})();

module.exports = Animator;